# $Id: Coin.spec 495 2009-05-22 08:53:59Z leolopes $
# Although this file is long, it is quite formulaic:
# For each package, define a name, a summary, and a version,
# then copy the appropriate header and header-devel from any of the existing packages
#
# This first preamble does not correspond to any package.
Summary: RPM Files for many Coin Packages
Name: CoinAll
Version: 1.2.0
Release: 1
License: CPL
Group: Development/Libraries
Source: http://www.coin-or.org/download/source/CoinAll/CoinAll-%{version}.tgz
Patch0: %{name}-%{version}-CoinMp-1.3.2.patch
Patch1: %{name}-%{version}-noRpaths.patch
BuildRoot: /var/tmp/%{name}-buildroot

%description
Built from the Coin-all distribution

%prep
%setup -q
# Whatever packages have been updated since less CoinAll.
%patch0 -p1
# Get rid of rpaths
%patch1 -p1

%configure

# Before configuring Ipopt, make sure we have a version of Mumps downloaded
cd ThirdParty/Mumps/
./get.Mumps
cd ../..

# run main configuration...
./configure --prefix=$RPM_BUILD_ROOT/usr 

# ... then remove rpaths.
# These two lines remove rpaths from the local libtool copy.
# They come from the Fedora Packaging Guide here:
# https://fedoraproject.org/wiki/Packaging/Guidelines
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# bash noRpathsPatch.sh

%build
make

echo ******************* BEGIN TESTS **********************
# since we are using rpaths, tell the package tests where to find the libs
for f in $(find $(pwd) -iname "*.so"); do
	LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$(dirname $f)
done
export LD_LIBRARY_PATH
# now run tests
echo $LD_LIBRARY_PATH
make test
echo ******************* END TESTS **********************

%install
make install

%clean
# rm -rf $RPM_BUILD_ROOT

#############################################################################
#############################################################################
# These are some variables for building on different distributions and
# architectures. Unfortunately for now you have to change them by hand.
%define CoinDist %{dist}.%{_arch}
#############################################################################
#############################################################################
%define CoinPackage CoinUtils
%define CoinPackageVersion 2.3.3
%define CoinPackageSummary "Utilities upon which most Coin packages depend."

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CoinUtils (Coin-or Utilities) is an open-source collection of classes
and functions that are generally useful to more than one COIN-OR
project. These utilities include:

    * Vector classes
    * Matrix classes
    * MPS file reading
    * Comparing floating point numbers with a tolerance  

%files -n %{CoinPackage}
/usr/lib/lib%{CoinPackage}.so.0.0.0
/usr/lib/lib%{CoinPackage}.so.0
/usr/lib/lib%{CoinPackage}.so
/usr/lib/lib%{CoinPackage}.la
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CoinUtils (Coin-or Utilities) is an open-source collection of classes
and functions that are generally useful to more than one COIN-OR
project. These utilities include:

    * Vector classes
    * Matrix classes
    * MPS file reading
    * Comparing floating point numbers with a tolerance 

%files -n %{CoinPackage}-devel
   /usr/include/coin/CoinAlloc.hpp
   /usr/include/coin/CoinDenseFactorization.hpp
   /usr/include/coin/CoinWarmStartPrimalDual.hpp
   /usr/include/coin/CoinWarmStartVector.hpp
/usr/include/coin/CoinUtilsConfig.h
/usr/include/coin/CoinBuild.hpp
/usr/include/coin/Coin_C_defines.h
/usr/include/coin/CoinDenseVector.hpp
/usr/include/coin/CoinDistance.hpp
/usr/include/coin/CoinError.hpp
/usr/include/coin/CoinFactorization.hpp
/usr/include/coin/CoinFileIO.hpp
/usr/include/coin/CoinFinite.hpp
/usr/include/coin/CoinFloatEqual.hpp
/usr/include/coin/CoinHelperFunctions.hpp
/usr/include/coin/CoinIndexedVector.hpp
/usr/include/coin/CoinLpIO.hpp
/usr/include/coin/CoinMessageHandler.hpp
/usr/include/coin/CoinMessage.hpp
/usr/include/coin/CoinModel.hpp
/usr/include/coin/CoinModelUseful.hpp
/usr/include/coin/CoinMpsIO.hpp
/usr/include/coin/CoinPackedMatrix.hpp
/usr/include/coin/CoinPackedVectorBase.hpp
/usr/include/coin/CoinPackedVector.hpp
/usr/include/coin/CoinParam.hpp
/usr/include/coin/CoinPragma.hpp
/usr/include/coin/CoinPresolveDoubleton.hpp
/usr/include/coin/CoinPresolveDual.hpp
/usr/include/coin/CoinPresolveDupcol.hpp
/usr/include/coin/CoinPresolveEmpty.hpp
/usr/include/coin/CoinPresolveFixed.hpp
/usr/include/coin/CoinPresolveForcing.hpp
/usr/include/coin/CoinPresolveImpliedFree.hpp
/usr/include/coin/CoinPresolveIsolated.hpp
/usr/include/coin/CoinPresolveMatrix.hpp
/usr/include/coin/CoinPresolvePsdebug.hpp
/usr/include/coin/CoinPresolveSingleton.hpp
/usr/include/coin/CoinPresolveSubst.hpp
/usr/include/coin/CoinPresolveTighten.hpp
/usr/include/coin/CoinPresolveTripleton.hpp
/usr/include/coin/CoinPresolveUseless.hpp
/usr/include/coin/CoinPresolveZeros.hpp
/usr/include/coin/CoinSearchTree.hpp
/usr/include/coin/CoinShallowPackedVector.hpp
/usr/include/coin/CoinSignal.hpp
/usr/include/coin/CoinSmartPtr.hpp
/usr/include/coin/CoinSnapshot.hpp
/usr/include/coin/CoinSort.hpp
/usr/include/coin/CoinTime.hpp
/usr/include/coin/CoinTypes.hpp
/usr/include/coin/CoinUtility.hpp
/usr/include/coin/CoinWarmStartBasis.hpp
/usr/include/coin/CoinWarmStartDual.hpp
/usr/include/coin/CoinWarmStart.hpp
/usr/include/coin/config_coinutils.h
   /usr/share/doc/coin/CoinUtils/coinutils_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Cgl
%define CoinPackageSummary "The Coin Cut Generation Libraries"
%define CoinPackageVersion 0.53.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
The COIN-OR Cut Generation Library (Cgl) is an open collection of cutting plane implementations 
("cut generators") for use in teaching, research, and applications. Cgl can be used with other
COIN-OR packages that make use of cuts, such as the mixed-integer linear programming solver Cbc. 
Each cut generator has its own Maintainer who leads the development of its functionality, 
testing, and documentation. See below for a listing of available generators. All the generators 
are combined in one library when Cgl is compiled. New contributions are welcome.

%files -n %{CoinPackage}
/usr/lib/lib%{CoinPackage}.la
/usr/lib/lib%{CoinPackage}.so
/usr/lib/lib%{CoinPackage}.so.0
/usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
The COIN-OR Cut Generation Library (Cgl) is an open collection of cutting plane implementations 
("cut generators") for use in teaching, research, and applications. Cgl can be used with other
COIN-OR packages that make use of cuts, such as the mixed-integer linear programming solver Cbc. 
Each cut generator has its own Maintainer who leads the development of its functionality, 
testing, and documentation. See below for a listing of available generators. All the generators 
are combined in one library when Cgl is compiled. New contributions are welcome.

%files -n %{CoinPackage}-devel
/usr/include/coin/config_cgl.h
/usr/include/coin/CglAllDifferent.hpp
/usr/include/coin/CglClique.hpp
/usr/include/coin/CglConfig.h
/usr/include/coin/CglCutGenerator.hpp
/usr/include/coin/CglDuplicateRow.hpp
/usr/include/coin/CglFlowCover.hpp
/usr/include/coin/CglGomory.hpp
/usr/include/coin/CglKnapsackCover.hpp
/usr/include/coin/CglLandP.hpp
/usr/include/coin/CglLandPSimplex.hpp
/usr/include/coin/CglLandPValidator.hpp
/usr/include/coin/CglLiftAndProject.hpp
/usr/include/coin/CglMessage.hpp
/usr/include/coin/CglMixedIntegerRounding.hpp
/usr/include/coin/CglMixedIntegerRounding2.hpp
/usr/include/coin/CglOddHole.hpp
/usr/include/coin/CglParam.hpp
/usr/include/coin/CglPreProcess.hpp
/usr/include/coin/CglProbing.hpp
/usr/include/coin/CglRedSplit.hpp
/usr/include/coin/CglRedSplitParam.hpp
/usr/include/coin/CglResidualCapacity.hpp
/usr/include/coin/CglSimpleRounding.hpp
/usr/include/coin/CglStored.hpp
/usr/include/coin/CglTreeInfo.hpp
/usr/include/coin/CglTwomir.hpp
   /usr/share/doc/coin/Cgl/cgl_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Clp
%define CoinPackageSummary "The Coin Linear Programming Solver"
%define CoinPackageVersion 1.8.2

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CLP is a high quality open-source LP solver. Its main strengths are its Dual and Primal Simplex
algorithms. It also has a barrier algorithm for Linear and Quadratic objectives. There are limited
facilities for Nonlinear and Quadratic objectives using the Simplex algorithm. It is available as a
library and as a standalone solver.

%files -n %{CoinPackage}
/usr/bin/clp
/usr/lib/libClp.la
/usr/lib/libClp.so
/usr/lib/libClp.so.0
/usr/lib/libClp.so.0.0.0
   /usr/share/doc/coin/Clp/AUTHORS
   /usr/share/doc/coin/Clp/LICENSE
   /usr/share/doc/coin/Clp/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CLP is a high quality open-source LP solver. Its main strengths are its Dual and Primal Simplex
algorithms. It also has a barrier algorithm for Linear and Quadratic objectives. There are limited
facilities for Nonlinear and Quadratic objectives using the Simplex algorithm. It is available as a
library and as a standalone solver.

%files -n %{CoinPackage}-devel
/usr/include/coin/config_clp.h
/usr/include/coin/ClpAmplObjective.hpp
/usr/include/coin/ClpCholeskyBase.hpp
/usr/include/coin/ClpCholeskyDense.hpp
/usr/include/coin/ClpCholeskyWssmp.hpp
/usr/include/coin/ClpConfig.h
/usr/include/coin/ClpConstraint.hpp
/usr/include/coin/ClpConstraintAmpl.hpp
/usr/include/coin/ClpConstraintLinear.hpp
/usr/include/coin/ClpConstraintQuadratic.hpp
/usr/include/coin/ClpDualRowDantzig.hpp
/usr/include/coin/ClpDualRowPivot.hpp
/usr/include/coin/ClpDualRowSteepest.hpp
   /usr/include/coin/ClpDummyMatrix.hpp
/usr/include/coin/ClpDynamicExampleMatrix.hpp
/usr/include/coin/ClpDynamicMatrix.hpp
/usr/include/coin/ClpEventHandler.hpp
/usr/include/coin/ClpFactorization.hpp
/usr/include/coin/ClpGubDynamicMatrix.hpp
/usr/include/coin/ClpGubMatrix.hpp
/usr/include/coin/ClpInterior.hpp
/usr/include/coin/ClpLinearObjective.hpp
/usr/include/coin/ClpMatrixBase.hpp
/usr/include/coin/ClpMessage.hpp
/usr/include/coin/ClpModel.hpp
/usr/include/coin/ClpNetworkMatrix.hpp
/usr/include/coin/ClpNode.hpp
/usr/include/coin/ClpNonLinearCost.hpp
/usr/include/coin/ClpObjective.hpp
/usr/include/coin/ClpPackedMatrix.hpp
/usr/include/coin/ClpParameters.hpp
/usr/include/coin/ClpPdcoBase.hpp
/usr/include/coin/ClpPlusMinusOneMatrix.hpp
/usr/include/coin/ClpPresolve.hpp
/usr/include/coin/ClpPrimalColumnDantzig.hpp
/usr/include/coin/ClpPrimalColumnPivot.hpp
/usr/include/coin/ClpPrimalColumnSteepest.hpp
/usr/include/coin/ClpQuadraticObjective.hpp
/usr/include/coin/ClpSimplex.hpp
/usr/include/coin/ClpSimplexNonlinear.hpp
/usr/include/coin/ClpSimplexOther.hpp
/usr/include/coin/ClpSimplexPrimal.hpp
/usr/include/coin/ClpSolve.hpp
/usr/include/coin/Clp_C_Interface.h
   /usr/include/coin/Idiot.hpp
   /usr/share/doc/coin/Clp/clp_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Cbc
%define CoinPackageSummary "COIN-OR Branch and Cut, an LP-based branch-and-cut library"
%define CoinPackageVersion 2.2.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CBC is an open-source MILP solver. It uses many of the COIN components and is designed to be used
with CLP or dylp. It is available as a library and as a standalone solver.

%files -n %{CoinPackage}
/usr/bin/cbc
/usr/lib/libCbc.la
/usr/lib/libCbc.so
/usr/lib/libCbc.so.0
/usr/lib/libCbc.so.0.0.0
   /usr/lib/libCbcSolver.la
   /usr/lib/libCbcSolver.so
   /usr/lib/libCbcSolver.so.0
   /usr/lib/libCbcSolver.so.0.0.0
/usr/share/doc/coin/Cbc/AUTHORS
/usr/share/doc/coin/Cbc/LICENSE
/usr/share/doc/coin/Cbc/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CBC is an open-source MILP solver. It uses many of the COIN components and is designed to be used
with CLP or dylp. It is available as a library and as a standalone solver.

%files -n %{CoinPackage}-devel
/usr/include/coin/config_cbc.h
/usr/include/coin/CbcBranchActual.hpp
/usr/include/coin/CbcBranchBase.hpp
/usr/include/coin/CbcBranchCut.hpp
/usr/include/coin/CbcBranchDynamic.hpp
/usr/include/coin/CbcBranchLotsize.hpp
/usr/include/coin/CbcCompareActual.hpp
/usr/include/coin/CbcCompareBase.hpp
/usr/include/coin/CbcConfig.h
/usr/include/coin/CbcCutGenerator.hpp
/usr/include/coin/CbcEventHandler.hpp
/usr/include/coin/CbcFathom.hpp
/usr/include/coin/CbcFeasibilityBase.hpp
/usr/include/coin/CbcHeuristic.hpp
/usr/include/coin/CbcHeuristicDive.hpp
/usr/include/coin/CbcHeuristicDiveCoefficient.hpp
/usr/include/coin/CbcHeuristicDiveFractional.hpp
/usr/include/coin/CbcHeuristicDiveGuided.hpp
/usr/include/coin/CbcHeuristicDiveVectorLength.hpp
/usr/include/coin/CbcHeuristicFPump.hpp
/usr/include/coin/CbcHeuristicGreedy.hpp
/usr/include/coin/CbcHeuristicLocal.hpp
/usr/include/coin/CbcHeuristicRINS.hpp
/usr/include/coin/CbcLinked.hpp
/usr/include/coin/CbcMessage.hpp
/usr/include/coin/CbcModel.hpp
/usr/include/coin/CbcNode.hpp
/usr/include/coin/CbcOrClpParam.hpp
/usr/include/coin/CbcSolver.hpp
/usr/include/coin/CbcStrategy.hpp
/usr/include/coin/CbcTree.hpp
/usr/include/coin/CbcTreeLocal.hpp
/usr/include/coin/Cbc_C_Interface.h
/usr/include/coin/CbcHeuristicDiveLineSearch.hpp
/usr/include/coin/CbcHeuristicDivePseudoCost.hpp
/usr/share/doc/coin/Cbc/cbc_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Dylp
%define CoinPackageSummary "Dynamic LP, an implementation of the dynamic simplex methods
%define CoinPackageVersion 1.4.4

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
DyLP is an open-source implementation of the dynamic simplex algorithm for linear programming. 
DyLP is pure C, heavily instrumented and commented, targetted toward algorithm development. 
An OSI interface, OsiDylp, is also available.

%files -n %{CoinPackage}
/usr/lib/libDylp.la
/usr/lib/libDylp.so
/usr/lib/libDylp.so.0
/usr/lib/libDylp.so.0.0.0
   /usr/share/doc/coin/DyLP/dylp_addlibs.txt

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
DyLP is an open-source implementation of the dynamic simplex algorithm for linear programming. 
DyLP is pure C, heavily instrumented and commented, targetted toward algorithm development. 
An OSI interface, OsiDylp, is also available.

%files -n %{CoinPackage}-devel
   /usr/include/coin/dy_consys.h
   /usr/include/coin/dy_vector.h
   /usr/include/coin/config_dylp.h
/usr/include/coin/dy_cmdint.h
/usr/include/coin/dylib_errs.h
/usr/include/coin/dylib_hash.h
/usr/include/coin/dylib_io.h
/usr/include/coin/dylib_std.h
/usr/include/coin/dylib_strrtns.h
/usr/include/coin/dylp.h
/usr/include/coin/DylpConfig.h
   /usr/share/doc/coin/DyLP/AUTHORS
   /usr/share/doc/coin/DyLP/LICENSE
   /usr/share/doc/coin/DyLP/README

#############################################################################
%package -n %{CoinPackage}-docs
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
License: CPL
Group: Applications/Engineering
BuildArch: noarch

%description -n %{CoinPackage}-docs
DyLP is an open-source implementation of the dynamic simplex algorithm for linear programming. 
DyLP is pure C, heavily instrumented and commented, targetted toward algorithm development. 
An OSI interface, OsiDylp, is also available.

%files -n %{CoinPackage}-docs
   /usr/share/doc/coin/DyLP/dylp.pdf
   /usr/share/doc/coin/DyLP/dylp.ps

#############################################################################
#############################################################################
%define CoinPackage Symphony
%define CoinPackageSummary "A callable library for solving mixed-integer linear programs"
%define CoinPackageVersion 5.1.10

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
SYMPHONY is an open-source generic MILP solver, callable library, and extensible framework 
for implementing customized solvers for mixed-integer linear programs (MILPs). 
SYMPHONY can be built in various sequential and parallel configurations for either distributed 
or shared memory architectures and can be used "out of the box" as a solver for generic 
mixed-integer linear programs or customized through a wide variety of user callback functions 
and control parameters. SYMPHONY has a number of advanced capabilities stemming from the 
research projects discussed above, including the ability to solve multi-objective MILPs, the 
ability to warm start its solution procedure, and the ability to perform basic sensitivity 
analyses. SYMPHONY has has been deployed in a variety of application areas, including 
computational biology, wireless telecommunications, supply chain management, 
transportation services, and air transportation.

%files -n %{CoinPackage}
/usr/bin/symphony
/usr/lib/libSym.la
/usr/lib/libSym.so
/usr/lib/libSym.so.0
/usr/lib/libSym.so.0.0.0
   /usr/share/doc/coin/SYMPHONY/AUTHORS
   /usr/share/doc/coin/SYMPHONY/LICENSE
   /usr/share/doc/coin/SYMPHONY/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
SYMPHONY is an open-source generic MILP solver, callable library, and extensible framework 
for implementing customized solvers for mixed-integer linear programs (MILPs). 
SYMPHONY can be built in various sequential and parallel configurations for either distributed 
or shared memory architectures and can be used "out of the box" as a solver for generic 
mixed-integer linear programs or customized through a wide variety of user callback functions 
and control parameters. SYMPHONY has a number of advanced capabilities stemming from the 
research projects discussed above, including the ability to solve multi-objective MILPs, the 
ability to warm start its solution procedure, and the ability to perform basic sensitivity 
analyses. SYMPHONY has has been deployed in a variety of application areas, including 
computational biology, wireless telecommunications, supply chain management, 
transportation services, and air transportation.

%files -n %{CoinPackage}-devel
   /usr/include/coin/config_sym.h
/usr/include/coin/SymConfig.h
   /usr/include/coin/SymWarmStart.hpp
   /usr/include/coin/symphony.h
   /usr/share/doc/coin/SYMPHONY/sym_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Vol
%define CoinPackageSummary "Volume Algorithm, a subgradient algorithm that also computes approximate primal solutions"
%define CoinPackageVersion 1.1.6

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
Vol (Volume Algorithm) is an open-source implementation of a subgradient method that produces 
primal as well as dual solutions. The primal solution comes from estimating the volumes below 
the faces of the dual problem. This is an approximate method so the primal vector might have 
small infeasiblities that are negligible in many practical settings. 
The original subgradient algorithm produces only dual solutions.

%files -n %{CoinPackage}
   /usr/lib/libVol.la
   /usr/lib/libVol.so
   /usr/lib/libVol.so.0
   /usr/lib/libVol.so.0.0.0
   /usr/share/doc/coin/Vol/AUTHORS
   /usr/share/doc/coin/Vol/LICENSE
   /usr/share/doc/coin/Vol/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
Vol (Volume Algorithm) is an open-source implementation of a subgradient method that produces 
primal as well as dual solutions. The primal solution comes from estimating the volumes below 
the faces of the dual problem. This is an approximate method so the primal vector might have 
small infeasiblities that are negligible in many practical settings. 
The original subgradient algorithm produces only dual solutions.

%files -n %{CoinPackage}-devel
   /usr/include/coin/VolVolume.hpp
   /usr/share/doc/coin/Vol/vol_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Osi
%define CoinPackageSummary "Open Solver Interface, a uniform API for calling embedded linear and mixed-integer programming solvers"
%define CoinPackageVersion 0.99.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
The COIN-OR Open Solver Interface is a uniform API for interacting with callable solver libraries. 
It supports linear programming solvers as well as the ability to "finish off" a mixed-integer 
problem calling the solver library's MIP solver. Currently, the following solvers are supported:
COIN-OR LP solver (OsiClp) and COIN-OR Branch and Cut solver (CoinBcp); CPLEX (OsiCpx); 
DyLP (OsiDylp); FortMP (OsiFmp); GLPK, the GNU Linear Programming Kit (OsiGlpk); Mosek (OsiMsk); 
OSL, the IBM Optimization Subroutine Library (OsiOsl); SYMPHONY (OsiSym); 
The Volume Algorithm (OsiVol); XPRESS-MP (OsiXpr).

%files -n %{CoinPackage}
/usr/lib/libOsi.la
/usr/lib/libOsi.so
/usr/lib/libOsi.so.0
/usr/lib/libOsi.so.0.0.0
   /usr/share/doc/coin/Osi/AUTHORS
   /usr/share/doc/coin/Osi/LICENSE
   /usr/share/doc/coin/Osi/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
The COIN-OR Open Solver Interface is a uniform API for interacting with callable solver libraries. 
It supports linear programming solvers as well as the ability to "finish off" a mixed-integer 
problem calling the solver library's MIP solver. Currently, the following solvers are supported:
COIN-OR LP solver (OsiClp) and COIN-OR Branch and Cut solver (CoinBcp); CPLEX (OsiCpx); 
DyLP (OsiDylp); FortMP (OsiFmp); GLPK, the GNU Linear Programming Kit (OsiGlpk); Mosek (OsiMsk); 
OSL, the IBM Optimization Subroutine Library (OsiOsl); SYMPHONY (OsiSym); 
The Volume Algorithm (OsiVol); XPRESS-MP (OsiXpr).

%files -n %{CoinPackage}-devel
   /usr/include/coin/config_osi.h
/usr/include/coin/OsiAuxInfo.hpp
/usr/include/coin/OsiBranchingObject.hpp
/usr/include/coin/OsiChooseVariable.hpp
/usr/include/coin/OsiColCut.hpp
/usr/include/coin/OsiCollections.hpp
/usr/include/coin/OsiConfig.h
/usr/include/coin/OsiCut.hpp
/usr/include/coin/OsiCuts.hpp
/usr/include/coin/OsiOpbdpSolve.hpp
/usr/include/coin/OsiPresolve.hpp
/usr/include/coin/OsiRowCut.hpp
/usr/include/coin/OsiRowCutDebugger.hpp
/usr/include/coin/OsiSolverInterface.hpp
/usr/include/coin/OsiSolverParameters.hpp
   /usr/share/doc/coin/Osi/osi_addlibs.txt

#############################################################################
%package -n OsiClp
Summary: Open Solver Interface (OSI) wrapper for Clp.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386

%description -n OsiClp
OSI Wrapper for Clp. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Clp
/usr/lib/libOsiClp.la
/usr/lib/libOsiClp.so
/usr/lib/libOsiClp.so.0
/usr/lib/libOsiClp.so.0.0.0

#############################################################################
%package -n OsiClp-devel
Summary: Open Solver Interface (OSI) wrapper for Clp.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386
Requires: OsiClp = %{version}

%description -n OsiClp-devel
OSI Wrapper for Clp. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Clp-devel
   /usr/include/coin/OsiClpParamMap.hpp
   /usr/include/coin/OsiClpSolverInterface.hpp

#############################################################################
%package -n OsiCbc
Summary: Open Solver Interface (OSI) wrapper for Cbc.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386

%description -n OsiCbc
OSI Wrapper for Cbc. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Cbc
/usr/lib/libOsiCbc.la
/usr/lib/libOsiCbc.so
/usr/lib/libOsiCbc.so.0
/usr/lib/libOsiCbc.so.0.0.0

#############################################################################
%package -n OsiCbc-devel
Summary: Open Solver Interface (OSI) wrapper for Cbc.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386
Requires: OsiCbc = %{version}

%description -n OsiCbc-devel
OSI Wrapper for Cbc. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Cbc-devel
   /usr/include/coin/OsiCbcSolverInterface.hpp

#############################################################################
%package -n OsiDylp
Summary: Open Solver Interface (OSI) wrapper for Dylp.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386

%description -n OsiDylp
OSI Wrapper for Dylp. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Dylp
/usr/lib/libOsiDylp.la
/usr/lib/libOsiDylp.so
/usr/lib/libOsiDylp.so.0
/usr/lib/libOsiDylp.so.0.0.0

#############################################################################
%package -n OsiDylp-devel
Summary: Open Solver Interface (OSI) wrapper for Dylp.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386
Requires: OsiDylp = %{version}

%description -n OsiDylp-devel
OSI Wrapper for Dylp. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Dylp-devel
  /usr/include/coin/OsiDylpMessages.hpp
   /usr/include/coin/OsiDylpSolverInterface.hpp
   /usr/include/coin/OsiDylpWarmStartBasis.hpp

#############################################################################
#############################################################################
%package -n OsiSymphony
Summary: Open Solver Interface (OSI) wrapper for Symphony.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386

%description -n OsiSymphony
OSI Wrapper for Symphony. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Symphony
/usr/lib/libOsiSym.la
/usr/lib/libOsiSym.so
/usr/lib/libOsiSym.so.0
/usr/lib/libOsiSym.so.0.0.0

#############################################################################
%package -n OsiSymphony-devel
Summary: Open Solver Interface (OSI) wrapper for Symphony.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386
Requires: OsiSymphony = %{version}

%description -n OsiSymphony-devel
OSI Wrapper for Symphony. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Symphony-devel
   /usr/include/coin/OsiSymSolverInterface.hpp
   /usr/include/coin/OsiSymSolverParameters.hpp

#############################################################################
#############################################################################
%package -n OsiVol
Summary: Open Solver Interface (OSI) wrapper for Vol.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386

%description -n OsiVol
OSI Wrapper for Vol. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Vol
   /usr/lib/libOsiVol.la
   /usr/lib/libOsiVol.so
   /usr/lib/libOsiVol.so.0
   /usr/lib/libOsiVol.so.0.0.0

#############################################################################
%package -n OsiVol-devel
Summary: Open Solver Interface (OSI) wrapper for Vol.
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Applications/Engineering
BuildArch: i386
Requires: OsiVol = %{version}

%description -n OsiVol-devel
OSI Wrapper for Vol. Please check the description of the Osi Package for more details.

%files -n %{CoinPackage}Vol-devel
/usr/include/coin/OsiVolSolverInterface.hpp

#############################################################################
#############################################################################
%define CoinPackage OptimizationServices
%define CoinPackageSummary "Standards and Methods for Optimization Web Services"
%define CoinPackageVersion 1.1.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
The objective of Optimization Services (OS) is to provide a set of standards for 
representing optimization instances, results, solver options, and communication between 
clients and solvers in a distributed environment using Web Services. This COIN-OR project 
provides source code for libraries and executable programs that implement OS standards. 
See the Optimization Services (OS) Home Site for more information.

%files -n %{CoinPackage}
   /usr/bin/OSFileUpload
   /usr/bin/OSSolverService
   /usr/lib/libOS.la
   /usr/lib/libOS.so
   /usr/lib/libOS.so.0
   /usr/lib/libOS.so.0.0.0
   /usr/share/doc/coin/OS/AUTHORS
   /usr/share/doc/coin/OS/LICENSE
   /usr/share/doc/coin/OS/README

#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
The objective of Optimization Services (OS) is to provide a set of standards for 
representing optimization instances, results, solver options, and communication between 
clients and solvers in a distributed environment using Web Services. This COIN-OR project 
provides source code for libraries and executable programs that implement OS standards. 
See the Optimization Services (OS) Home Site for more information.

%files -n %{CoinPackage}-devel
   /usr/include/coin/config_os.h
   /usr/include/coin/OSConfig.h
   /usr/include/coin/OSDataStructures.h
   /usr/include/coin/OSExpressionTree.h
   /usr/include/coin/OSInstance.h
   /usr/include/coin/OSMatlab.h
   /usr/include/coin/OSParameters.h
   /usr/include/coin/OSResult.h
   /usr/include/coin/OSSolverAgent.h
   /usr/include/coin/OShL.h
   /usr/include/coin/OSiLParserData.h
   /usr/include/coin/OSiLReader.h
   /usr/include/coin/OSiLWriter.h
   /usr/include/coin/OSmps2osil.h
   /usr/include/coin/OSnLNode.h
   /usr/include/coin/OSnl2osil.h
   /usr/include/coin/OSrLParserData.h
   /usr/include/coin/OSrLReader.h
   /usr/include/coin/OSrLWriter.h
   /usr/include/coin/OSBase64.h
   /usr/include/coin/OSCoinSolver.h
   /usr/include/coin/OSCommonUtil.h
   /usr/include/coin/OSDefaultSolver.h
   /usr/include/coin/OSErrorClass.h
   /usr/include/coin/OSFileUtil.h
   /usr/include/coin/OSMathUtil.h
   /usr/include/coin/OSOptionsStruc.h
   /usr/include/coin/OSParseosil.tab.hpp
   /usr/include/coin/OSParseosrl.tab.hpp
   /usr/include/coin/OSWSUtil.h
   /usr/include/coin/OSdtoa.h
   /usr/share/doc/coin/OS/os_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Cppad
%define CoinPackageSummary "A Package for Differentiation of C++ Algorithms"
%define CoinPackageVersion 20080919.0

%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}-devel
We refer to the step by step conversion from an algorithm that 
computes function values to an algorithm that computes derivative values 
as Algorithmic Differentiation (often referred to as Automatic Differentiation.) 
Given a C++ algorithm that computes function values, 
CppAD generates an algorithm that computes its derivative values. 
A brief introduction to Algorithmic Differentiation can be found in Wikipedia. 
The web site autodiff.org is dedicated to research about, and promoting the use, of AD.
IMPORTANT: This rpm contains a distribution of CppAD licensed under the CPL.
It is otherwise identical to a Fedora version of the rpm with the same major version
number, which is licensed under a different license.

%files -n %{CoinPackage}-devel
   /usr/include/cppad/CheckNumericType.h
   /usr/include/cppad/CheckSimpleVector.h
   /usr/include/cppad/CppAD.h
   /usr/include/cppad/CppAD_vector.h
   /usr/include/cppad/ErrorHandler.h
   /usr/include/cppad/LuFactor.h
   /usr/include/cppad/LuInvert.h
   /usr/include/cppad/LuSolve.h
   /usr/include/cppad/NearEqual.h
   /usr/include/cppad/OdeErrControl.h
   /usr/include/cppad/OdeGear.h
   /usr/include/cppad/OdeGearControl.h
   /usr/include/cppad/Poly.h
   /usr/include/cppad/PowInt.h
   /usr/include/cppad/RombergMul.h
   /usr/include/cppad/RombergOne.h
   /usr/include/cppad/Rosen34.h
   /usr/include/cppad/Runge45.h
   /usr/include/cppad/SpeedTest.h
   /usr/include/cppad/TrackNewDel.h
   /usr/include/cppad/check_numeric_type.hpp
   /usr/include/cppad/check_simple_vector.hpp
   /usr/include/cppad/config.h
   /usr/include/cppad/cppad.hpp
   /usr/include/cppad/error_handler.hpp
   /usr/include/cppad/lu_factor.hpp
   /usr/include/cppad/lu_invert.hpp
   /usr/include/cppad/lu_solve.hpp
   /usr/include/cppad/nan.hpp
   /usr/include/cppad/near_equal.hpp
   /usr/include/cppad/ode_err_control.hpp
   /usr/include/cppad/ode_gear.hpp
   /usr/include/cppad/ode_gear_control.hpp
   /usr/include/cppad/poly.hpp
   /usr/include/cppad/pow_int.hpp
   /usr/include/cppad/romberg_mul.hpp
   /usr/include/cppad/romberg_one.hpp
   /usr/include/cppad/rosen_34.hpp
   /usr/include/cppad/runge_45.hpp
   /usr/include/cppad/vector.hpp
   /usr/include/cppad/declare.hpp
   /usr/include/cppad/track_new_del.hpp
   /usr/include/cppad/std_math_unary.hpp
   /usr/include/cppad/local/abs.hpp
   /usr/include/cppad/local/abs_op.hpp
   /usr/include/cppad/local/acos_op.hpp
   /usr/include/cppad/local/ad.hpp
   /usr/include/cppad/local/ad_binary.hpp
   /usr/include/cppad/local/ad_copy.hpp
   /usr/include/cppad/local/ad_fun.hpp
   /usr/include/cppad/local/ad_tape.hpp
   /usr/include/cppad/local/ad_valued.hpp
   /usr/include/cppad/local/add.hpp
   /usr/include/cppad/local/add_eq.hpp
   /usr/include/cppad/local/add_op.hpp
   /usr/include/cppad/local/arithmetic.hpp
   /usr/include/cppad/local/asin_op.hpp
   /usr/include/cppad/local/atan2.hpp
   /usr/include/cppad/local/atan_op.hpp
   /usr/include/cppad/local/base_complex.hpp
   /usr/include/cppad/local/bender_quad.hpp
   /usr/include/cppad/local/bool_fun.hpp
   /usr/include/cppad/local/bool_fun_link.hpp
   /usr/include/cppad/local/bool_valued.hpp
   /usr/include/cppad/local/cap_taylor.hpp
   /usr/include/cppad/local/compare.hpp
   /usr/include/cppad/local/compute_assign.hpp
   /usr/include/cppad/local/cond_exp.hpp
   /usr/include/cppad/local/convert.hpp
   /usr/include/cppad/local/cppad_assert.hpp
   /usr/include/cppad/local/default.hpp
   /usr/include/cppad/local/define.hpp
   /usr/include/cppad/local/dependent.hpp
   /usr/include/cppad/local/discrete.hpp
   /usr/include/cppad/local/div.hpp
   /usr/include/cppad/local/div_eq.hpp
   /usr/include/cppad/local/div_op.hpp
   /usr/include/cppad/local/drivers.hpp
   /usr/include/cppad/local/equal_op_seq.hpp
   /usr/include/cppad/local/erf.hpp
   /usr/include/cppad/local/exp_op.hpp
   /usr/include/cppad/local/for_jac_sweep.hpp
   /usr/include/cppad/local/for_one.hpp
   /usr/include/cppad/local/for_sparse_jac.hpp
   /usr/include/cppad/local/for_two.hpp
   /usr/include/cppad/local/forward.hpp
   /usr/include/cppad/local/forward_sweep.hpp
   /usr/include/cppad/local/fun_check.hpp
   /usr/include/cppad/local/fun_construct.hpp
   /usr/include/cppad/local/fun_eval.hpp
   /usr/include/cppad/local/hessian.hpp
   /usr/include/cppad/local/identical.hpp
   /usr/include/cppad/local/independent.hpp
   /usr/include/cppad/local/integer.hpp
   /usr/include/cppad/local/jacobian.hpp
   /usr/include/cppad/local/log_op.hpp
   /usr/include/cppad/local/lu_ratio.hpp
   /usr/include/cppad/local/math_other.hpp
   /usr/include/cppad/local/mul.hpp
   /usr/include/cppad/local/mul_eq.hpp
   /usr/include/cppad/local/mul_op.hpp
   /usr/include/cppad/local/near_equal_ext.hpp
   /usr/include/cppad/local/omp_max_thread.hpp
   /usr/include/cppad/local/op.hpp
   /usr/include/cppad/local/op_code.hpp
   /usr/include/cppad/local/ordered.hpp
   /usr/include/cppad/local/output.hpp
   /usr/include/cppad/local/par_var.hpp
   /usr/include/cppad/local/pow.hpp
   /usr/include/cppad/local/preprocessor.hpp
   /usr/include/cppad/local/print_for.hpp
   /usr/include/cppad/local/rev_hes_sweep.hpp
   /usr/include/cppad/local/rev_jac_sweep.hpp
   /usr/include/cppad/local/rev_one.hpp
   /usr/include/cppad/local/rev_sparse_hes.hpp
   /usr/include/cppad/local/rev_sparse_jac.hpp
   /usr/include/cppad/local/rev_two.hpp
   /usr/include/cppad/local/reverse.hpp
   /usr/include/cppad/local/reverse_sweep.hpp
   /usr/include/cppad/local/sin_cos.hpp
   /usr/include/cppad/local/sparse.hpp
   /usr/include/cppad/local/sqrt_op.hpp
   /usr/include/cppad/local/sub.hpp
   /usr/include/cppad/local/sub_eq.hpp
   /usr/include/cppad/local/sub_op.hpp
   /usr/include/cppad/local/tape_link.hpp
   /usr/include/cppad/local/test_vector.hpp
   /usr/include/cppad/local/unary_minus.hpp
   /usr/include/cppad/local/unary_plus.hpp
   /usr/include/cppad/local/undef.hpp
   /usr/include/cppad/local/user_ad.hpp
   /usr/include/cppad/local/value.hpp
   /usr/include/cppad/local/var2par.hpp
   /usr/include/cppad/local/vec_ad.hpp
   /usr/include/cppad/local/declare_ad.hpp
   /usr/include/cppad/local/forward0sweep.hpp
   /usr/include/cppad/local/player.hpp
   /usr/include/cppad/local/recorder.hpp
   /usr/include/cppad/local/sparse_hessian.hpp
   /usr/include/cppad/local/sparse_jacobian.hpp
   /usr/include/cppad/local/std_math_ad.hpp
   /usr/include/cppad/speed/det_by_lu.hpp
   /usr/include/cppad/speed/det_by_minor.hpp
   /usr/include/cppad/speed/det_grad_33.hpp
   /usr/include/cppad/speed/det_of_minor.hpp
   /usr/include/cppad/speed/uniform_01.hpp
   /usr/include/cppad/speed_test.hpp
   /usr/include/cppad/speed/det_33.hpp
   /usr/include/cppad/speed/ode_evaluate.hpp
   /usr/include/cppad/speed/sparse_evaluate.hpp

#############################################################################
#############################################################################
%define CoinPackage Smi
%define CoinPackageSummary "The Stochastic modeling Interface"
%define CoinPackageVersion 0.92.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
SMI stands for Stochastic Modeling Interface. It is an interface for
problems in which uncertainty and optimization appear together. There
are many modeling and algorithmic approaches that could belong here,
like: recourse programming, chance constrained programming, stochastic
control and dynamic programming, robust optimization, etc, etc. SMI is
intended to be like OSI in the sense that an SmiXX object is an
implementation derived from a base class that takes care of a number
of commonly encountered programming issues, like handling probability
distributions, managing problem generation, interacting with solvers
to obtain solution information, etc.

%files -n %{CoinPackage}
/usr/lib/libSmi.la
/usr/lib/libSmi.so
/usr/lib/libSmi.so.0
/usr/lib/libSmi.so.0.0.0
   /usr/share/doc/coin/Smi/AUTHORS
   /usr/share/doc/coin/Smi/LICENSE
   /usr/share/doc/coin/Smi/README


#############################################################################
%package -n %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
DyLP is an open-source implementation of the dynamic simplex algorithm for linear programming. 
DyLP is pure C, heavily instrumented and commented, targetted toward algorithm development. 
An OSI interface, OsiSmi, is also available.

%files -n %{CoinPackage}-devel
/usr/include/coin/SmiCoreCombineRule.hpp
/usr/include/coin/SmiDiscreteDistribution.hpp
/usr/include/coin/SmiLinearData.hpp
/usr/include/coin/SmiMessage.hpp
/usr/include/coin/SmiScenarioTree.hpp
/usr/include/coin/SmiScnData.hpp
/usr/include/coin/SmiScnModel.hpp

#############################################################################
#############################################################################
%define CoinPackage CoinMP
%define CoinPackageSummary "A C library to access much of LP and IP Coin functionality."
%define CoinPackageVersion 1.2.1

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CoinMP is a C-API library that supports most of the functionality of 
CLP (Coin LP), CBC (Coin Branch-and-Cut), and CGL (Cut Generation Library) projects. 
When compiled for Windows it generates a CoinMP.dll that can be readily used 
in other Windows C/C++ projects. 
When compiled for Unix it generates a CoinMP.so library that can be similarly 
used in other Unix C/C++ projects. 
The project includes a precompiled CoinMP.dll that is ready to be used as is 
in other Windows applications.

%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CoinMP is a C-API library that supports most of the functionality of 
CLP (Coin LP), CBC (Coin Branch-and-Cut), and CGL (Cut Generation Library) projects. 
When compiled for Windows it generates a CoinMP.dll that can be readily used 
in other Windows C/C++ projects. 
When compiled for Unix it generates a CoinMP.so library that can be similarly 
used in other Unix C/C++ projects. 
The project includes a precompiled CoinMP.dll that is ready to be used as is 
in other Windows applications.

%files -n %{CoinPackage}-devel
   /usr/share/doc/coin/CoinMP/examples/Makefile
   /usr/share/doc/coin/CoinMP/examples/example.c
   /usr/include/coin/CoinMP.h
   /usr/include/coin/CoinMPConfig.h
   /usr/include/coin/config_coinmp.h
   /usr/share/doc/coin/CoinMP/coinmp_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Alps
%define CoinPackageSummary "The Abstract Library for Parallel Search (ALPS), part of CHiPPS."
%define CoinPackageVersion 1.0.0

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}-devel
   /usr/include/coin/Alps.h
   /usr/include/coin/AlpsConfig.h
   /usr/include/coin/AlpsEncoded.h
   /usr/include/coin/AlpsEnumProcessT.h
   /usr/include/coin/AlpsHelperFunctions.h
   /usr/include/coin/AlpsKnowledge.h
   /usr/include/coin/AlpsKnowledgeBroker.h
   /usr/include/coin/AlpsKnowledgeBrokerMPI.h
   /usr/include/coin/AlpsKnowledgeBrokerSerial.h
   /usr/include/coin/AlpsKnowledgePool.h
   /usr/include/coin/AlpsMessage.h
   /usr/include/coin/AlpsModel.h
   /usr/include/coin/AlpsNodeDesc.h
   /usr/include/coin/AlpsNodePool.h
   /usr/include/coin/AlpsParameterBase.h
   /usr/include/coin/AlpsParams.h
   /usr/include/coin/AlpsPriorityQueue.h
   /usr/include/coin/AlpsSearchStrategy.h
   /usr/include/coin/AlpsSearchStrategyBase.h
   /usr/include/coin/AlpsSolution.h
   /usr/include/coin/AlpsSolutionPool.h
   /usr/include/coin/AlpsSubTree.h
   /usr/include/coin/AlpsSubTreePool.h
   /usr/include/coin/AlpsTime.h
   /usr/include/coin/AlpsTreeNode.h
   /usr/include/coin/config_alps.h
   /usr/share/doc/coin/Alps/alps_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Bcps
%define CoinPackageSummary "(BiCePS) is a data management layer built on top of ALPS for implementing relaxation-based branch and bound algorithms, part of CHiPPS"
%define CoinPackageVersion 0.9.0

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}-devel
   /usr/include/coin/Bcps.h
   /usr/include/coin/BcpsBranchObject.h
   /usr/include/coin/BcpsBranchStrategy.h
   /usr/include/coin/BcpsConfig.h
   /usr/include/coin/BcpsInterface.h
   /usr/include/coin/BcpsLicense.h
   /usr/include/coin/BcpsMessage.h
   /usr/include/coin/BcpsModel.h
   /usr/include/coin/BcpsNodeDesc.h
   /usr/include/coin/BcpsObject.h
   /usr/include/coin/BcpsObjectPool.h
   /usr/include/coin/BcpsSolution.h
   /usr/include/coin/BcpsSubTree.h
   /usr/include/coin/BcpsTreeNode.h
   /usr/include/coin/config_bcps.h
   /usr/share/doc/coin/Bcps/bcps_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Blis
%define CoinPackageSummary "(BLIS) is a concretization of the BiCePS layer for solving mixed-integer linear programs, part of CHiPPS."
%define CoinPackageVersion 0.9.0

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README
   /usr/bin/blis

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
CHiPPS is the COIN-OR High-Performance Parallel Search Framework, 
a framework for implementing parallel algorithms based on tree search. 
The current CHiPPS architecture consists of three layers. 
The Abstract Library for Parallel Search (ALPS) is the base layer of a hierarchy 
consisting of implementations of various tree search algorithms for specific problem types. 
The Branch, Constrain, and Price Software (BiCePS) is a data management layer 
built on top of ALPS for implementing relaxation-based branch and bound algorithms. 
The BiCePS Linear Integer Solver (BLIS) is a concretization of the BiCePS layer 
for solving mixed-integer linear programs. 
ALPS, BiCePS, and BLIS are sub-repostories of the CHiPPS Subversion repository.

%files -n %{CoinPackage}-devel
   /usr/include/coin/Blis.h
   /usr/include/coin/BlisBranchObjectInt.h
   /usr/include/coin/BlisBranchStrategyMaxInf.h
   /usr/include/coin/BlisBranchStrategyPseudo.h
   /usr/include/coin/BlisBranchStrategyRel.h
   /usr/include/coin/BlisBranchStrategyStrong.h
   /usr/include/coin/BlisConGenerator.h
   /usr/include/coin/BlisConfig.h
   /usr/include/coin/BlisConstraint.h
   /usr/include/coin/BlisHelp.h
   /usr/include/coin/BlisHeurRound.h
   /usr/include/coin/BlisHeuristic.h
   /usr/include/coin/BlisLicense.h
   /usr/include/coin/BlisMessage.h
   /usr/include/coin/BlisModel.h
   /usr/include/coin/BlisNodeDesc.h
   /usr/include/coin/BlisObjectInt.h
   /usr/include/coin/BlisParams.h
   /usr/include/coin/BlisPresolve.h
   /usr/include/coin/BlisPseudo.h
   /usr/include/coin/BlisSolution.h
   /usr/include/coin/BlisSubTree.h
   /usr/include/coin/BlisTreeNode.h
   /usr/include/coin/BlisVariable.h
   /usr/include/coin/config_blis.h
   /usr/share/doc/coin/Blis/blis_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage FlopCpp
%define CoinPackageSummary "An open source algebraic modelling language implemented as a C++ class library. "
%define CoinPackageVersion 1.0.5

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
Using FLOPC++, linear optimization models can be specified in a declarative style, 
similar to algebraic modelling languages such as GAMS and AMPL, within a C++ program. 
As a result the traditional strengths of algebraic modelling languages are preserved, 
while embedding linear optimization models in software applications is facilitated.
FLOPC++ can be used as a substitute for traditional modelling languages, 
when modelling linear optimization problems, 
but its principal strength lies in the fact that the modelling facilities 
are combined with a powerful general purpose programming language. 
This combination is essential for implementing efficient algorithms 
(using linear optimization for subproblems), 
integrating optimization models in user applications, etc. 
%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
Using FLOPC++, linear optimization models can be specified in a declarative style, 
similar to algebraic modelling languages such as GAMS and AMPL, within a C++ program. 
As a result the traditional strengths of algebraic modelling languages are preserved, 
while embedding linear optimization models in software applications is facilitated.
FLOPC++ can be used as a substitute for traditional modelling languages, 
when modelling linear optimization problems, 
but its principal strength lies in the fact that the modelling facilities 
are combined with a powerful general purpose programming language. 
This combination is essential for implementing efficient algorithms 
(using linear optimization for subproblems), 
integrating optimization models in user applications, etc. 

%files -n %{CoinPackage}-devel
   /usr/include/coin/FlopCppConfig.h
   /usr/include/coin/MP_boolean.hpp
   /usr/include/coin/MP_constant.hpp
   /usr/include/coin/MP_constraint.hpp
   /usr/include/coin/MP_data.hpp
   /usr/include/coin/MP_domain.hpp
   /usr/include/coin/MP_expression.hpp
   /usr/include/coin/MP_index.hpp
   /usr/include/coin/MP_model.hpp
   /usr/include/coin/MP_set.hpp
   /usr/include/coin/MP_utilities.hpp
   /usr/include/coin/MP_variable.hpp
   /usr/include/coin/config_flopcpp.h
   /usr/include/coin/flopc.hpp
   /usr/share/doc/coin/FlopCpp/flopcpp_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Bcp
%define CoinPackageSummary "A parallel framework for implementing branch, cut, and price algorithms for solving mixed integer programs (MIPs)."
%define CoinPackageVersion 1.2.0

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
BCP is a parallel framework for implementing branch, cut, and price algorithms 
for solving mixed integer programs (MIPs). 
BCP provides the user with an object-oriented framework 
that can be used to develop an efficient problem class specific MIP solver 
without all the implementational effort 
involved with implementing a branch and bound framework from scratch.

%files -n %{CoinPackage}
   /usr/lib/lib%{CoinPackage}.la
   /usr/lib/lib%{CoinPackage}.so
   /usr/lib/lib%{CoinPackage}.so.0
   /usr/lib/lib%{CoinPackage}.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
BCP is a parallel framework for implementing branch, cut, and price algorithms 
for solving mixed integer programs (MIPs). 
BCP provides the user with an object-oriented framework 
that can be used to develop an efficient problem class specific MIP solver 
without all the implementational effort 
involved with implementing a branch and bound framework from scratch.

%files -n %{CoinPackage}-devel
   /usr/include/coin/BCP_USER.hpp
   /usr/include/coin/BCP_branch.hpp
   /usr/include/coin/BCP_buffer.hpp
   /usr/include/coin/BCP_cg.hpp
   /usr/include/coin/BCP_cg_param.hpp
   /usr/include/coin/BCP_cg_user.hpp
   /usr/include/coin/BCP_cut.hpp
   /usr/include/coin/BCP_enum.hpp
   /usr/include/coin/BCP_enum_branch.hpp
   /usr/include/coin/BCP_enum_process_t.hpp
   /usr/include/coin/BCP_enum_tm.hpp
   /usr/include/coin/BCP_error.hpp
   /usr/include/coin/BCP_functions.hpp
   /usr/include/coin/BCP_indexed_pricing.hpp
   /usr/include/coin/BCP_lp.hpp
   /usr/include/coin/BCP_lp_branch.hpp
   /usr/include/coin/BCP_lp_functions.hpp
   /usr/include/coin/BCP_lp_main_loop.hpp
   /usr/include/coin/BCP_lp_node.hpp
   /usr/include/coin/BCP_lp_param.hpp
   /usr/include/coin/BCP_lp_pool.hpp
   /usr/include/coin/BCP_lp_result.hpp
   /usr/include/coin/BCP_lp_user.hpp
   /usr/include/coin/BCP_main_fun.hpp
   /usr/include/coin/BCP_math.hpp
   /usr/include/coin/BCP_matrix.hpp
   /usr/include/coin/BCP_mempool.hpp
   /usr/include/coin/BCP_message.hpp
   /usr/include/coin/BCP_message_mpi.hpp
   /usr/include/coin/BCP_message_pvm.hpp
   /usr/include/coin/BCP_message_single.hpp
   /usr/include/coin/BCP_message_tag.hpp
   /usr/include/coin/BCP_node_change.hpp
   /usr/include/coin/BCP_obj_change.hpp
   /usr/include/coin/BCP_os.hpp
   /usr/include/coin/BCP_parameters.hpp
   /usr/include/coin/BCP_problem_core.hpp
   /usr/include/coin/BCP_process.hpp
   /usr/include/coin/BCP_set_intersects.hpp
   /usr/include/coin/BCP_solution.hpp
   /usr/include/coin/BCP_string.hpp
   /usr/include/coin/BCP_tm.hpp
   /usr/include/coin/BCP_tm_functions.hpp
   /usr/include/coin/BCP_tm_node.hpp
   /usr/include/coin/BCP_tm_param.hpp
   /usr/include/coin/BCP_tm_user.hpp
   /usr/include/coin/BCP_tmstorage.hpp
   /usr/include/coin/BCP_var.hpp
   /usr/include/coin/BCP_vector.hpp
   /usr/include/coin/BCP_vector_bool.hpp
   /usr/include/coin/BCP_vector_change.hpp
   /usr/include/coin/BCP_vector_char.hpp
   /usr/include/coin/BCP_vector_double.hpp
   /usr/include/coin/BCP_vector_general.hpp
   /usr/include/coin/BCP_vector_int.hpp
   /usr/include/coin/BCP_vector_sanity.hpp
   /usr/include/coin/BCP_vector_short.hpp
   /usr/include/coin/BCP_vg.hpp
   /usr/include/coin/BCP_vg_param.hpp
   /usr/include/coin/BCP_vg_user.hpp
   /usr/include/coin/BCP_warmstart.hpp
   /usr/include/coin/BCP_warmstart_basis.hpp
   /usr/include/coin/BCP_warmstart_dual.hpp
   /usr/include/coin/BCP_warmstart_primaldual.hpp
   /usr/include/coin/BcpConfig.h
   /usr/include/coin/config_bcp.h
   /usr/share/doc/coin/Bcp/bcp_addlibs.txt

#############################################################################
#############################################################################
%define CoinPackage Ipopt
%define CoinPackageSummary "A software package for large-scale nonlinear optimization."
%define CoinPackageVersion 3.5.4

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
Ipopt (Interior Point OPTimizer, pronounced I-P-Opt) is a software package 
for large-scale nonlinear optimization. 
It is designed to find (local) solutions of mathematical optimization problems 
of the from

   min     f(x)
x in R^n

s.t.       g_L <= g(x) <= g_U
           x_L <=  x   <= x_U

where f(x): R^n --> R is the objective function, 
and g(x): R^n --> R^m are the constraint functions. 
The vectors g_L and g_U denote the lower and upper bounds on the constraints, 
and the vectors x_L and x_U are the bounds on the variables x. 
The functions f(x) and g(x) can be nonlinear and nonconvex, 
but should be twice continuously differentiable. 
Note that equality constraints can be formulated in the above formulation 
by setting the corresponding components of g_L and g_U to the same value. 

%files -n %{CoinPackage}
   /usr/lib/libipopt.la
   /usr/lib/libipopt.so
   /usr/lib/libipopt.so.0
   /usr/lib/libipopt.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
Ipopt (Interior Point OPTimizer, pronounced I-P-Opt) is a software package 
for large-scale nonlinear optimization. 
It is designed to find (local) solutions of mathematical optimization problems 
of the from

   min     f(x)
x in R^n

s.t.       g_L <= g(x) <= g_U
           x_L <=  x   <= x_U

where f(x): R^n --> R is the objective function, 
and g(x): R^n --> R^m are the constraint functions. 
The vectors g_L and g_U denote the lower and upper bounds on the constraints, 
and the vectors x_L and x_U are the bounds on the variables x. 
The functions f(x) and g(x) can be nonlinear and nonconvex, 
but should be twice continuously differentiable. 

%files -n %{CoinPackage}-devel
   /usr/include/coin/IpAlgTypes.hpp
   /usr/include/coin/IpCachedResults.hpp
   /usr/include/coin/IpDebug.hpp
   /usr/include/coin/IpException.hpp
   /usr/include/coin/IpIpoptApplication.hpp
   /usr/include/coin/IpJournalist.hpp
   /usr/include/coin/IpMatrix.hpp
   /usr/include/coin/IpNLP.hpp
   /usr/include/coin/IpObserver.hpp
   /usr/include/coin/IpOptionsList.hpp
   /usr/include/coin/IpReferenced.hpp
   /usr/include/coin/IpRegOptions.hpp
   /usr/include/coin/IpReturnCodes.h
   /usr/include/coin/IpReturnCodes.hpp
   /usr/include/coin/IpReturnCodes.inc
   /usr/include/coin/IpReturnCodes_inc.h
   /usr/include/coin/IpSmartPtr.hpp
   /usr/include/coin/IpSolveStatistics.hpp
   /usr/include/coin/IpStdCInterface.h
   /usr/include/coin/IpSymMatrix.hpp
   /usr/include/coin/IpTNLP.hpp
   /usr/include/coin/IpTNLPReducer.hpp
   /usr/include/coin/IpTaggedObject.hpp
   /usr/include/coin/IpTimedTask.hpp
   /usr/include/coin/IpTypes.hpp
   /usr/include/coin/IpUtils.hpp
   /usr/include/coin/IpVector.hpp
   /usr/include/coin/IpoptConfig.h
   /usr/include/coin/OSIpoptSolver.h
   /usr/include/coin/config_ipopt.h
   /usr/share/doc/coin/Ipopt/ipopt_addlibs_cpp.txt
   /usr/share/doc/coin/Ipopt/ipopt_addlibs_f.txt

#############################################################################
#############################################################################
%define CoinPackage Bonmin
%define CoinPackageSummary "An experimental C++ code for solving general Mixed Integer NonLinear Programming problems"
%define CoinPackageVersion 0.100.2

%package -n  %{CoinPackage}
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386

%description -n %{CoinPackage}
Bonmin (Basic Open-source Nonlinear Mixed INteger programming) 
is an experimental open-source C++ code for solving general 
MINLP (Mixed Integer NonLinear Programming) problems of the form:

   min     f(x)

s.t.       g_L <= g(x) <= g_U
           x_L <=  x   <= x_U
           x_i in Z for all i in I and,
           x_i in R for all i not in I.

where f(x): R^n --> R, g(x): R^n --> R^m are 
twice continuously differentiable functions and I is a subset of {1,..,n}.

%files -n %{CoinPackage}
   /usr/lib/libbonmin.la
   /usr/lib/libbonmin.so
   /usr/lib/libbonmin.so.0
   /usr/lib/libbonmin.so.0.0.0
   /usr/share/doc/coin/%{CoinPackage}/AUTHORS
   /usr/share/doc/coin/%{CoinPackage}/LICENSE
   /usr/share/doc/coin/%{CoinPackage}/README

#############################################################################
%package -n  %{CoinPackage}-devel
Summary: %{CoinPackageSummary}
Version: %{CoinPackageVersion}
Release: 1
License: CPL
Group: Development/Libraries
BuildArch: i386
Requires: %{CoinPackage} = %{version}

%description -n %{CoinPackage}-devel
Bonmin (Basic Open-source Nonlinear Mixed INteger programming) 
is an experimental open-source C++ code for solving general 
MINLP (Mixed Integer NonLinear Programming) problems of the form:

   min     f(x)

s.t.       g_L <= g(x) <= g_U
           x_L <=  x   <= x_U
           x_i in Z for all i in I and,
           x_i in R for all i not in I.

where f(x): R^n --> R, g(x): R^n --> R^m are 
twice continuously differentiable functions and I is a subset of {1,..,n}.

%files -n %{CoinPackage}-devel
   /usr/include/coin/BonAuxInfos.hpp
   /usr/include/coin/BonBabInfos.hpp
   /usr/include/coin/BonBabSetupBase.hpp
   /usr/include/coin/BonBonminSetup.hpp
   /usr/include/coin/BonBranchingTQP.hpp
   /usr/include/coin/BonCbc.hpp
   /usr/include/coin/BonCbcLpStrategy.hpp
   /usr/include/coin/BonCbcNlpStrategy.hpp
   /usr/include/coin/BonCbcNode.hpp
   /usr/include/coin/BonChooseVariable.hpp
   /usr/include/coin/BonCurvBranchingSolver.hpp
   /usr/include/coin/BonCutStrengthener.hpp
   /usr/include/coin/BonDiver.hpp
   /usr/include/coin/BonDummyHeuristic.hpp
   /usr/include/coin/BonEcpCuts.hpp
   /usr/include/coin/BonGuessHeuristic.hpp
   /usr/include/coin/BonIpoptInteriorWarmStarter.hpp
   /usr/include/coin/BonIpoptSolver.hpp
   /usr/include/coin/BonIpoptWarmStart.hpp
   /usr/include/coin/BonLpBranchingSolver.hpp
   /usr/include/coin/BonOACutGenerator2.hpp
   /usr/include/coin/BonOAMessages.hpp
   /usr/include/coin/BonOaDecBase.hpp
   /usr/include/coin/BonOaFeasChecker.hpp
   /usr/include/coin/BonOaNlpOptim.hpp
   /usr/include/coin/BonOsiTMINLPInterface.hpp
   /usr/include/coin/BonPseudoCosts.hpp
   /usr/include/coin/BonQpBranchingSolver.hpp
   /usr/include/coin/BonRegisteredOptions.hpp
   /usr/include/coin/BonTMINLP.hpp
   /usr/include/coin/BonTMINLP2TNLP.hpp
   /usr/include/coin/BonTNLP2FPNLP.hpp
   /usr/include/coin/BonTNLPSolver.hpp
   /usr/include/coin/BonTypes.hpp
   /usr/include/coin/BonminConfig.h
   /usr/include/coin/OSBonminSolver.h
   /usr/include/coin/config_bonmin.h

#############################################################################
#############################################################################
# %define CoinPackage CoinMumps
# %define CoinPackageSummary "A public domain linear solver. Coin-OR will distribute this temporarily since Coin-OR software depends on it."
# %define CoinPackageVersion 1.2.0
# 
# %package -n  %{CoinPackage}
# Summary: %{CoinPackageSummary}
# Version: %{CoinPackageVersion}
# Release: 1
# License: CPL
# Group: Development/Libraries
# BuildArch: i386
# 
# %description -n %{CoinPackage}
# 
# %files -n %{CoinPackage}
#    /usr/lib/libcoinmumps.la
#    /usr/lib/libcoinmumps.so
#    /usr/lib/libcoinmumps.so.0
#    /usr/lib/libcoinmumps.so.0.0.0
# 
#############################################################################
#############################################################################
#############################################################################
%changelog
* Mon Oct 6 2008 Leo Lopes <leo@sie.arizona.edu>
- No rpaths, CoinAll 1.2.0, added CoinMP 1.3.2

* Tue Sep 30 2008 Leo Lopes <leo@sie.arizona.edu>
- Updated for CoinAll 1.2, added CoinMP

* Wed Jun 13 2008 Leo Lopes <leo@sie.arizona.edu>
- Updated for CoinAll 1.1

* Wed Dec 19 2007 Leo Lopes <leo@sie.arizona.edu>
- Added 3 files from the GLPK distribution to DyLP

* Mon Nov 12 2007 Leo Lopes <leo@sie.arizona.edu>
- Added Clp, Cbc, Cgl, Smi, Symphony, Vol, Osi, OsiClp, OsiCbc, OsiDylp, OsiSym, OsiVol, OS

* Fri Nov 2 2007 Leo Lopes <leo@sie.arizona.edu>
- Used the OS version 1.0.0 release to create rpms

* Wed Sep 19 2007 Leo Lopes <leo@sie.arizona.edu>
- Added a patch to temporarily fix Makefile for version 2.1.1

* Sat Aug 11 2007 Leo Lopes <leo@sie.arizona.edu>
- First version of RPM

